@@ -271,7 +271,6 @@ anno = anno_barplot(matrix(nc = 2, c(1:10, 10:1)), beside = TRUE, gp = gpar(fill
 draw(anno, test = "a matrix with fill")
 
 
-
 ##### test anno_boxplot #####
 set.seed(123)
 m = matrix(rnorm(100), 10)
@@ -343,6 +342,12 @@ draw(anno, test = "heatmap")
 anno = anno_density(t(m), which = "row", type = "heatmap", heatmap_colors = c("white", "orange"))
 draw(anno, test = "heatmap, colors")
 
+anno = anno_density(t(m), which = "row", xlim = c(-2, 2))
+draw(anno, test = "normal density")
+anno = anno_density(t(m), which = "row", type = "violin", xlim = c(-2, 2))
+draw(anno, test = "violin")
+anno = anno_density(t(m), which = "row", type = "heatmap", xlim = c(-2, 2))
+draw(anno, test = "heatmap")
 
 ###### anno_mark ###
 if(0) {
